@@ -47,7 +47,13 @@ class KijijiApi:
             # Kijiji sometimes takes a bit longer to respond to API requests
             # e.g. for loading conversations
             timeout = httpx.Timeout(30.0, connect=30.0)
-            self.session = httpx.Client(timeout=timeout, headers=self.headers)
+
+            def log_response(response):
+                request = response.request
+                response.read()  # Must read response body in order to access elapsed time
+                print(f"HTTP {request.method} {request.url} response time: {response.elapsed}")
+
+            self.session = httpx.Client(timeout=timeout, headers=self.headers, event_hooks={'response': [log_response]})
 
     def login(self, username, password):
         """Login to Kijiji
@@ -373,8 +379,9 @@ class KijijiApi:
             return doc
         else:
             raise KijijiApiException(self._error_reason(doc))
-    
-    def geo_location(self, postal_code):
+
+    @staticmethod
+    def geo_location(postal_code):
         # pgeocode.Nominatim.query_postal_code only uses the first three characters to do the lookup for Canadian postal codes
         postalcode = postal_code[:3]
         try:
@@ -384,7 +391,7 @@ class KijijiApi:
             raise KijijiApiException(f'Error acquiring geo location data: {e}')
         else:
             return location
-    
+
     @staticmethod
     def _headers_with_auth(user_id, token):
         return {'X-ECG-Authorization-User': f'id="{user_id}", token="{token}"'}
@@ -399,15 +406,25 @@ class KijijiApi:
 
     @staticmethod
     def _error_reason(doc):
+        messages = []
         try:
             base = doc['api-base-error']
-            if 'api-field-errors' in base and base['api-field-errors']:
-                base = base['api-field-errors']['api-field-error']
-            error = base['api-errors']['api-error']
-            message = error['message']
+
+            # Three different possible error types - search through all
+            for err_type in ['api-error', 'api-field-error', 'api-debug-error']:
+                err_type_plural = err_type + 's'  # Error type name with an appended 's'
+
+                if err_type_plural in base and base[err_type_plural]:
+                    if err_type in base[err_type_plural] and base[err_type_plural][err_type]:
+                        # Check if there are multiple error messages in the same error type
+                        if isinstance(base[err_type_plural][err_type], list):
+                            for err in base[err_type_plural][err_type]:
+                                messages.append(err_type + ': ' + err['message'])
+                        else:
+                            messages.append(err_type + ': ' + base[err_type_plural][err_type]['message'])
         except (TypeError, KeyError):
             return 'Unknown API error'
-        return message
+        return messages
 
     @staticmethod
     def _error_reason_mobile(doc):
