@@ -12,6 +12,7 @@ kijiji_api = KijijiApi()
 
 @main.route('/')
 def index():
+    """Redirect to appropriate page depending on if user is currently logged in."""
     if current_user.is_authenticated:
         return redirect(url_for('.home'))
     else:
@@ -21,20 +22,23 @@ def index():
 @main.route('/home')
 @login_required
 def home():
+    """Show home page."""
     data = kijiji_api.get_ad(current_user.id, current_user.token)
     return render_template('home.html', name=current_user.name, data=data)
 
 
 @main.app_template_filter('islist')
 def islist(data):
+    """Return true if value is a list object."""
     return isinstance(data, list)
 
 
-# Convert datetime string to datetime object
-# datetime object will get converted back to a string via __repr__() when rendered in a template
-# Kijiji API returns datetime strings in full ISO 8601 format; e.g. '2020-06-20T20:57:42.000Z'
 @main.app_template_filter('datetime')
 def format_datetime(date, fmt=None):
+    """Convert datetime string to datetime object.
+    datetime object will get converted back to a string via __repr__() when rendered in a template.
+    Kijiji API returns datetime strings in full ISO 8601 format; e.g. '2020-06-20T20:57:42.000Z'.
+    """
     if fmt is None:
         fmt = '%Y-%m-%dT%H:%M:%S.%f'
 
@@ -45,9 +49,9 @@ def format_datetime(date, fmt=None):
         return None
 
 
-# Get list of thumbnail image urls
 @main.app_template_filter('imgthumbs')
 def get_img_thumbs(data):
+    """Get list of thumbnail image urls."""
     try:
         pics = data['pic:pictures']['pic:picture']
     except (TypeError, KeyError):
@@ -69,15 +73,15 @@ def get_img_thumbs(data):
     return urls
 
 
-# Get first thumbnail image url
 @main.app_template_filter('imgthumbfirst')
 def get_img_thumb_first(data):
+    """Get first thumbnail image url."""
     return get_img_thumbs(data)[0]
 
 
-# Get public website ad url
 @main.app_template_filter('adurl')
 def get_ad_url(data):
+    """Get public website ad url."""
     try:
         links = data['ad:link']
     except (TypeError, KeyError):
@@ -89,9 +93,9 @@ def get_ad_url(data):
             return link['@href']
 
 
-# Convert ad rank to page number
 @main.app_template_filter('adpage')
 def get_ad_page_number(data):
+    """Convert ad rank to page number."""
     try:
         return int(math.ceil(int(data) / 20))
     except (TypeError, ValueError):
